@@ -6,7 +6,7 @@ from devsecops_engine_tools.engine_sast.engine_secret.src.domain.usecases.set_in
 
 def engine_secret_scan(devops_platform_gateway, tool_gateway, dict_args, tool, tool_deserealizator, git_gateway, secret_tool):
     exclusions = devops_platform_gateway.get_remote_config(
-        dict_args["remote_config_repo"], "engine_sast/engine_secret/Exclusions.json"
+        dict_args["remote_config_repo"], "engine_sast/engine_secret/Exclusions.json", dict_args["remote_config_branch"]
     )
     secret_scan = SecretScan(tool_gateway, devops_platform_gateway, tool_deserealizator, git_gateway)
     config_tool, skip_tool_isp = secret_scan.complete_config_tool(dict_args, tool)
